shithub: libvpx

Download patch

ref: dc262df7b5828b079f7e15cd7dbb296b7c281de8
parent: 66aca163f5017fc50276f1c3025f2b2cc08aa010
parent: 5086716a17bb9f2fac0b0d3af8329dc57e23489b
author: Marco Paniconi <marpan@google.com>
date: Mon May 14 14:13:59 EDT 2018

Merge "vp9-svc: Add conditon to asserts on prediction pattern."

--- a/vp9/encoder/vp9_svc_layercontext.c
+++ b/vp9/encoder/vp9_svc_layercontext.c
@@ -947,8 +947,10 @@
 void vp9_svc_assert_constraints_pattern(VP9_COMP *const cpi) {
   SVC *const svc = &cpi->svc;
   // For fixed/non-flexible mode, and with CONSTRAINED frame drop
   // mode (default), the folllowing constraint are expected.
   if (svc->temporal_layering_mode != VP9E_TEMPORAL_LAYERING_MODE_BYPASS &&
+      svc->disable_inter_layer_pred == INTER_LAYER_PRED_ON &&
       svc->framedrop_mode == CONSTRAINED_LAYER_DROP) {
     if (!cpi->svc.layer_context[cpi->svc.temporal_layer_id].is_key_frame) {
       // On non-key frames: LAST is always temporal reference, GOLDEN is
@@ -947,8 +947,10 @@
   SVC *const svc = &cpi->svc;
   // For fixed/non-flexible mode, and with CONSTRAINED frame drop
-  // mode (default), the folllowing constraint are expected.
+  // mode (default), the folllowing constraint are expected, when
+  // inter-layer prediciton is on (default).
   if (svc->temporal_layering_mode != VP9E_TEMPORAL_LAYERING_MODE_BYPASS &&